@@ -14,8 +14,9 @@ import StringIO
 import html2text
 DB_FORMAT = '%Y-%m-%d'
 FRAMEWORK_VERSION = '0.3.1' 
-DB_PATH = '/home/user/.mPIM/mnotes.db'
-DB_IMG_FOLDER = '/home/user/.mPIM/mnotes_img/'
+HOME_PATH = os.path.expanduser("~")
+DB_PATH = HOME_PATH + '/.mPIM/mnotes.db'
+DB_IMG_FOLDER = HOME_PATH + '/.mPIM/mnotes_img/'
 
 class Database:
         def __init__(self,path=None):
@@ -24,7 +25,7 @@ class Database:
           if path != None:
             self.path = path
           else:
-            self.path = '/home/user/.mPIM/mnotes.db'
+            self.path = DB_PATH
           try:
             self.db = sqlite3.connect(self.path)
             self.db.text_factory = str
@@ -40,7 +41,7 @@ class Database:
 
         def _create(self):
           #Try to create the folder in case of
-          commands.getoutput("mkdir /home/user/.mPIM/")
+          commands.getoutput("mkdir "+HOME_PATH +"/.mPIM/")
           self.db = sqlite3.connect(self.path)
           self.cursor = self.db.cursor()
           self.cursor.execute('CREATE TABLE notes (uuid TEXT PRIMARY KEY, title DATETIME, description TEXT,type INTEGER,google_id TEXT, google_last_updat TEXT)')
@@ -176,12 +177,12 @@ class Note:
             self.have_draw =True
 
         def get_photo_path(self):
-          if os.path.exists('/home/user/.mPIM/mnotes_img/')==False:
-            commands.getoutput("mkdir /home/user/.mPIM/mnotes_img/")
+          if os.path.exists(DB_IMG_FOLDER)==False:
+            commands.getoutput("mkdir " + DB_IMG_FOLDER)
           return DB_IMG_FOLDER+'photos_'+self.uuid+'.jpg'
         def get_draw_path(self):
-          if os.path.exists('/home/user/.mPIM/mnotes_img/')==False:
-            commands.getoutput("mkdir /home/user/.mPIM/mnotes_img/")
+          if os.path.exists(DB_IMG_FOLDER)==False:
+            commands.getoutput("mkdir " + DB_IMG_FOLDER)
           return DB_IMG_FOLDER+'draw_'+self.uuid+'.jpg'
 
         def load_from_db(self,suuid):
