@@ -40,7 +40,7 @@ class mNotes(object):
 
   __pretty_app_name__ = "mNotes"
   __app_name__ = "mNotes"
-  __version__ = "0.3.0"
+  __version__ = "0.3.1"
   __context__ = "net.khertan.mnotes"
 
   _glade_files = [
@@ -502,8 +502,9 @@ class mNotes(object):
     column_title.add_attribute(titletextrenderer, 'style', 4)
     self.notesListTree.append_column(column_title)
 
-    self._notes_loader_process = threading.Thread(target=self._load_noteslist,args=[self._notesList])
-    self._notes_loader_process.start()
+#    self._notes_loader_process = threading.Thread(target=self._load_noteslist,args=[self._notesList])
+#    self._notes_loader_process.start()
+    self._load_noteslist_bg()
     gtk.gdk.threads_leave()
 
     #Menu
@@ -630,11 +631,9 @@ class mNotes(object):
       notes_uuid_list =  mnotes_framework.NotesList().get_all_notes()
     else:
       notes_uuid_list =  mnotes_framework.NotesList().get_notes_with_text(self._search_text)
-
-#    notes_uuid_list =  mnotes_framework.NotesList().get_all_notes()
     notes_uuid_list.sort()
     note = None
-    #gtk.gdk.threads_enter()
+
     for (title,uuid) in notes_uuid_list:
       if self._notesList != notesList:
         return False
@@ -644,6 +643,7 @@ class mNotes(object):
     self._pijama_color()
     self.notesListTree.set_cursor(0)
     gtk.gdk.threads_leave()
+
     return False
 
   def click_cam(self):
